=========
Changelog
=========

Version 1.4
===========
- dropped mandatory dependency to *requests_kerberos_proxy*. Is only needed behind proxy servers
- added pre-commit support
- added readthedocs links

Version 1.3
===========
- Reorganised code

Version 1.2
===========

- Added request_kerberos_proxy such that this tool can be run behind a proxy
- Updated documentation and unit test in order to publish to pypi

Version 1.1
===========

- First setup for python api to internet.nl
